@@ -11,21 +11,17 @@ def main():
   print 'Exporting Caltech101 dataset to redistributable HDF5 file "' + dbfile + '"'
   
   # Import an existing viset 
-  print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile)
-  for (im,annotation) in db.read(n_skip=100):
+  print 'Displaying training/testing split in viset (VISion dataSET) "' + dbfile + '"'
+  db = Viset(dbfile, split='2fold')
+  for (im,annotation) in db['train']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im)
-    sleep(0.1)
-
-  for (im,annotation) in db.read(category=['airplanes','Faces'], n_skip=10):
+    imshow(im, title=annotation['category'])
+  for (im,annotation) in db['test']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    imshow(im)
-    sleep(1)
+    imshow(im, title=annotation['category'])
 
   # Cleanup cached data (optional)
-  print 'Deleting all cached data in "' + db.cachedir + '"'  
-  db.delete()
+  # db.delete()
   
 if __name__ == '__main__':
   main()
