@@ -4,20 +4,18 @@ from viset.show import imshow
 
 if __name__ == '__main__':
   # Create a new viset
-  print 'Creating vision dataset for Caltech101 dataset'
+  print 'Creating vision dataset for Caltech256 dataset'
   dbfile = Caltech256().export()
   print 'Exporting Caltech256 dataset to redistributable HDF5 file "' + dbfile + '"'
   
   # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile)
-  for (im,annotation) in db.read(n_skip=100):
+  db = Viset(dbfile, datastep=100)
+  for (im,annotation) in db['dataset']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imshow(im)
-    sleep(0.2)
 
   # Cleanup cached data (optional)
-  print 'Deleting all cached data in "' + db.cachedir + '"'  
-  db.delete()
+  #db.delete()
 
   
