@@ -10,11 +10,8 @@ if __name__ == '__main__':
   
   # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile)
-  for (im,annotation) in db.read(n_skip=100):
+  db = Viset(dbfile, datastep=100)
+  for (im,annotation) in db['dataset']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     if im is not None:
       imshow(im)
-      sleep(0.2)
-
-
